@@ -28,15 +28,14 @@
 #include "../fieldformat.h"
 #include "../tellico_debug.h"
 
-#include <klineedit.h>
-
+#include <QLineEdit>
 #include <QValidator>
 #include <QBoxLayout>
 
 using Tellico::GUI::NumberFieldWidget;
 
 NumberFieldWidget::NumberFieldWidget(Tellico::Data::FieldPtr field_, QWidget* parent_)
-    : FieldWidget(field_, parent_), m_lineEdit(0), m_spinBox(0) {
+    : FieldWidget(field_, parent_), m_lineEdit(nullptr), m_spinBox(nullptr) {
 
   if(field_->hasFlag(Data::Field::AllowMultiple)) {
     initLineEdit();
@@ -48,7 +47,7 @@ NumberFieldWidget::NumberFieldWidget(Tellico::Data::FieldPtr field_, QWidget* pa
 }
 
 void NumberFieldWidget::initLineEdit() {
-  m_lineEdit = new KLineEdit(this);
+  m_lineEdit = new QLineEdit(this);
   connect(m_lineEdit, SIGNAL(textChanged(const QString&)), SLOT(checkModified()));
 
   // regexp is any number of digits followed optionally by any number of
@@ -119,12 +118,12 @@ void NumberFieldWidget::updateFieldHook(Tellico::Data::FieldPtr, Tellico::Data::
   if(wasLineEdit && !nowLineEdit) {
     layout()->removeWidget(m_lineEdit);
     delete m_lineEdit;
-    m_lineEdit = 0;
+    m_lineEdit = nullptr;
     initSpinBox();
   } else if(!wasLineEdit && nowLineEdit) {
     layout()->removeWidget(m_spinBox);
     delete m_spinBox;
-    m_spinBox = 0;
+    m_spinBox = nullptr;
     initLineEdit();
   }
 
@@ -139,5 +138,3 @@ QWidget* NumberFieldWidget::widget() {
   }
   return m_lineEdit;
 }
-
-#include "numberfieldwidget.moc"
